@@ -33,7 +33,7 @@
 subset.cv <- function(x, select = NULL, ...) {
     if(is.null(select)) return(x)
     x$cv <- x$cv[select]
-    x$sd <- x$sd[select]
+    x$se <- x$se[select]
     if(!is.null(reps <- x$reps)) x$reps <- reps[, select, drop=FALSE]
     x
 }
@@ -45,7 +45,7 @@ subset.cv <- function(x, select = NULL, ...) {
 
 subset.cvSelect <- function(x, subset = NULL, select = NULL, ...) {
     cv <- x$cv
-    sd <- x$sd
+    se <- x$se
     cvNames <- cvNames(x)
     reps <- x$reps
     # extract subset of models
@@ -55,7 +55,7 @@ subset.cvSelect <- function(x, subset = NULL, select = NULL, ...) {
             x$best <- x$best[select]
             select <- c("Fit", select)  # also select column describing models
             x$cv <- cv[, select, drop=FALSE]
-            x$sd <- sd[, select, drop=FALSE]
+            x$se <- se[, select, drop=FALSE]
             if(!is.null(reps)) x$reps <- reps[, select, drop=FALSE]
         }
     } else {
@@ -66,12 +66,12 @@ subset.cvSelect <- function(x, subset = NULL, select = NULL, ...) {
         # extract CV results for the models to keep
         if(is.null(select)) {
             cv <- cv[subset, , drop=FALSE]
-            sd <- sd[subset, , drop=FALSE]
+            se <- se[subset, , drop=FALSE]
         } else {
             if(!is.character(select)) select <- cvNames[select]
             select <- c("Fit", select)  # also select column describing models
             cv <- cv[subset, select, drop=FALSE]
-            sd <- sd[subset, select, drop=FALSE]
+            se <- se[subset, select, drop=FALSE]
         }
         fits <- cv$Fit  # models to keep
         haveFactor <- is.factor(fits)
@@ -79,20 +79,20 @@ subset.cvSelect <- function(x, subset = NULL, select = NULL, ...) {
             # for a factor, unused levels should be dropped and 
             # remaining levels should be in the right order
             fits <- as.character(fits)
-            cv$Fit <- sd$Fit <- factor(fits, levels=fits)
+            cv$Fit <- se$Fit <- factor(fits, levels=fits)
         }
         x$cv <- cv
-        x$sd <- sd
+        x$se <- se
         # find best model among the remaining ones
         if(is.null(x$selectBest)) x$selectBest <- "min"
-        if(is.null(x$sdFactor)) x$sdFactor <- NA
+        if(is.null(x$seFactor)) x$seFactor <- NA
         if(ncol(cv) > 1) {
             if(x$selectBest == "min") {
                 x$best <- sapply(cv[, -1, drop=FALSE], selectMin)
             } else {
                 x$best <- sapply(names(cv)[-1], 
                     function(j) {
-                        selectHastie(cv[, j], sd[, j], sdFactor=x$sdFactor)
+                        selectHastie(cv[, j], se[, j], seFactor=x$seFactor)
                     })
             }
         } else x$best <- x$best[integer()]  # this ensures empty integer vector
